# coding: utf-8

# flake8: noqa
"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.2 (Build: 20250811)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


if __import__("typing").TYPE_CHECKING:
    # import models into model package
    from poodle_async_mini.models.core_course_get_contents_parameters_options_inner import CoreCourseGetContentsParametersOptionsInner
    from poodle_async_mini.models.core_course_get_contents_response_inner import CoreCourseGetContentsResponseInner
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner import CoreCourseGetContentsResponseInnerModulesInner
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_activitybadge import CoreCourseGetContentsResponseInnerModulesInnerActivitybadge
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_activitybadge_one_of import CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOf
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_activitybadge_one_of_badgeextraattributes_inner import CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOfBadgeextraattributesInner
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_completiondata import CoreCourseGetContentsResponseInnerModulesInnerCompletiondata
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_completiondata_details_inner import CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInner
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_completiondata_details_inner_rulevalue import CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInnerRulevalue
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_contents_inner import CoreCourseGetContentsResponseInnerModulesInnerContentsInner
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_contents_inner_tags_inner import CoreCourseGetContentsResponseInnerModulesInnerContentsInnerTagsInner
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_contentsinfo import CoreCourseGetContentsResponseInnerModulesInnerContentsinfo
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_dates_inner import CoreCourseGetContentsResponseInnerModulesInnerDatesInner
    from poodle_async_mini.models.core_enrol_get_users_courses_response_inner import CoreEnrolGetUsersCoursesResponseInner
    from poodle_async_mini.models.core_enrol_get_users_courses_response_inner_overviewfiles_inner import CoreEnrolGetUsersCoursesResponseInnerOverviewfilesInner
    from poodle_async_mini.models.core_group_get_course_groups_response_inner import CoreGroupGetCourseGroupsResponseInner
    from poodle_async_mini.models.core_webservice_get_site_info_response import CoreWebserviceGetSiteInfoResponse
    from poodle_async_mini.models.core_webservice_get_site_info_response_advancedfeatures_inner import CoreWebserviceGetSiteInfoResponseAdvancedfeaturesInner
    from poodle_async_mini.models.core_webservice_get_site_info_response_functions_inner import CoreWebserviceGetSiteInfoResponseFunctionsInner
    from poodle_async_mini.models.gradereport_user_get_grade_items_response import GradereportUserGetGradeItemsResponse
    from poodle_async_mini.models.gradereport_user_get_grade_items_response_usergrades_inner import GradereportUserGetGradeItemsResponseUsergradesInner
    from poodle_async_mini.models.gradereport_user_get_grade_items_response_usergrades_inner_gradeitems_inner import GradereportUserGetGradeItemsResponseUsergradesInnerGradeitemsInner
    from poodle_async_mini.models.gradereport_user_get_grade_items_response_warnings_inner import GradereportUserGetGradeItemsResponseWarningsInner
    from poodle_async_mini.models.login_token200_response import LoginToken200Response
    from poodle_async_mini.models.mod_assign_get_assignments_response import ModAssignGetAssignmentsResponse
    from poodle_async_mini.models.mod_assign_get_assignments_response_courses_inner import ModAssignGetAssignmentsResponseCoursesInner
    from poodle_async_mini.models.mod_assign_get_assignments_response_courses_inner_assignments_inner import ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInner
    from poodle_async_mini.models.mod_assign_get_assignments_response_courses_inner_assignments_inner_configs_inner import ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInnerConfigsInner
    from poodle_async_mini.models.mod_assign_get_assignments_response_warnings_inner import ModAssignGetAssignmentsResponseWarningsInner
    from poodle_async_mini.models.mod_assign_get_submissions_response import ModAssignGetSubmissionsResponse
    from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner import ModAssignGetSubmissionsResponseAssignmentsInner
    from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner_submissions_inner import ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInner
    from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner_submissions_inner_plugins_inner import ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInner
    from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner_submissions_inner_plugins_inner_editorfields_inner import ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInnerEditorfieldsInner
    from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner_submissions_inner_plugins_inner_fileareas_inner import ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInnerFileareasInner
    from poodle_async_mini.models.mod_assign_list_participants_response_inner import ModAssignListParticipantsResponseInner
    from poodle_async_mini.models.mod_assign_list_participants_response_inner_customfields_inner import ModAssignListParticipantsResponseInnerCustomfieldsInner
    from poodle_async_mini.models.mod_assign_list_participants_response_inner_enrolledcourses_inner import ModAssignListParticipantsResponseInnerEnrolledcoursesInner
    from poodle_async_mini.models.mod_assign_list_participants_response_inner_groups_inner import ModAssignListParticipantsResponseInnerGroupsInner
    from poodle_async_mini.models.mod_assign_list_participants_response_inner_preferences_inner import ModAssignListParticipantsResponseInnerPreferencesInner
    from poodle_async_mini.models.mod_assign_list_participants_response_inner_roles_inner import ModAssignListParticipantsResponseInnerRolesInner
    from poodle_async_mini.models.tool_mobile_get_public_config_response import ToolMobileGetPublicConfigResponse
    from poodle_async_mini.models.tool_mobile_get_public_config_response_identityproviders_inner import ToolMobileGetPublicConfigResponseIdentityprovidersInner
    
else:
    from lazy_imports import LazyModule, as_package, load

    load(
        LazyModule(
            *as_package(__file__),
            """# import models into model package
from poodle_async_mini.models.core_course_get_contents_parameters_options_inner import CoreCourseGetContentsParametersOptionsInner
from poodle_async_mini.models.core_course_get_contents_response_inner import CoreCourseGetContentsResponseInner
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner import CoreCourseGetContentsResponseInnerModulesInner
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_activitybadge import CoreCourseGetContentsResponseInnerModulesInnerActivitybadge
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_activitybadge_one_of import CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOf
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_activitybadge_one_of_badgeextraattributes_inner import CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOfBadgeextraattributesInner
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_completiondata import CoreCourseGetContentsResponseInnerModulesInnerCompletiondata
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_completiondata_details_inner import CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInner
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_completiondata_details_inner_rulevalue import CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInnerRulevalue
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_contents_inner import CoreCourseGetContentsResponseInnerModulesInnerContentsInner
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_contents_inner_tags_inner import CoreCourseGetContentsResponseInnerModulesInnerContentsInnerTagsInner
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_contentsinfo import CoreCourseGetContentsResponseInnerModulesInnerContentsinfo
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_dates_inner import CoreCourseGetContentsResponseInnerModulesInnerDatesInner
from poodle_async_mini.models.core_enrol_get_users_courses_response_inner import CoreEnrolGetUsersCoursesResponseInner
from poodle_async_mini.models.core_enrol_get_users_courses_response_inner_overviewfiles_inner import CoreEnrolGetUsersCoursesResponseInnerOverviewfilesInner
from poodle_async_mini.models.core_group_get_course_groups_response_inner import CoreGroupGetCourseGroupsResponseInner
from poodle_async_mini.models.core_webservice_get_site_info_response import CoreWebserviceGetSiteInfoResponse
from poodle_async_mini.models.core_webservice_get_site_info_response_advancedfeatures_inner import CoreWebserviceGetSiteInfoResponseAdvancedfeaturesInner
from poodle_async_mini.models.core_webservice_get_site_info_response_functions_inner import CoreWebserviceGetSiteInfoResponseFunctionsInner
from poodle_async_mini.models.gradereport_user_get_grade_items_response import GradereportUserGetGradeItemsResponse
from poodle_async_mini.models.gradereport_user_get_grade_items_response_usergrades_inner import GradereportUserGetGradeItemsResponseUsergradesInner
from poodle_async_mini.models.gradereport_user_get_grade_items_response_usergrades_inner_gradeitems_inner import GradereportUserGetGradeItemsResponseUsergradesInnerGradeitemsInner
from poodle_async_mini.models.gradereport_user_get_grade_items_response_warnings_inner import GradereportUserGetGradeItemsResponseWarningsInner
from poodle_async_mini.models.login_token200_response import LoginToken200Response
from poodle_async_mini.models.mod_assign_get_assignments_response import ModAssignGetAssignmentsResponse
from poodle_async_mini.models.mod_assign_get_assignments_response_courses_inner import ModAssignGetAssignmentsResponseCoursesInner
from poodle_async_mini.models.mod_assign_get_assignments_response_courses_inner_assignments_inner import ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInner
from poodle_async_mini.models.mod_assign_get_assignments_response_courses_inner_assignments_inner_configs_inner import ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInnerConfigsInner
from poodle_async_mini.models.mod_assign_get_assignments_response_warnings_inner import ModAssignGetAssignmentsResponseWarningsInner
from poodle_async_mini.models.mod_assign_get_submissions_response import ModAssignGetSubmissionsResponse
from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner import ModAssignGetSubmissionsResponseAssignmentsInner
from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner_submissions_inner import ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInner
from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner_submissions_inner_plugins_inner import ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInner
from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner_submissions_inner_plugins_inner_editorfields_inner import ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInnerEditorfieldsInner
from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner_submissions_inner_plugins_inner_fileareas_inner import ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInnerFileareasInner
from poodle_async_mini.models.mod_assign_list_participants_response_inner import ModAssignListParticipantsResponseInner
from poodle_async_mini.models.mod_assign_list_participants_response_inner_customfields_inner import ModAssignListParticipantsResponseInnerCustomfieldsInner
from poodle_async_mini.models.mod_assign_list_participants_response_inner_enrolledcourses_inner import ModAssignListParticipantsResponseInnerEnrolledcoursesInner
from poodle_async_mini.models.mod_assign_list_participants_response_inner_groups_inner import ModAssignListParticipantsResponseInnerGroupsInner
from poodle_async_mini.models.mod_assign_list_participants_response_inner_preferences_inner import ModAssignListParticipantsResponseInnerPreferencesInner
from poodle_async_mini.models.mod_assign_list_participants_response_inner_roles_inner import ModAssignListParticipantsResponseInnerRolesInner
from poodle_async_mini.models.tool_mobile_get_public_config_response import ToolMobileGetPublicConfigResponse
from poodle_async_mini.models.tool_mobile_get_public_config_response_identityproviders_inner import ToolMobileGetPublicConfigResponseIdentityprovidersInner

""",
            name=__name__,
            doc=__doc__,
        )
    )
