# coding: utf-8

# flake8: noqa

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.2 (Build: 20250811)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "5.0.2.post2"

# Define package exports
__all__ = [
    "DefaultApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "settings",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "CoreCourseGetContentsParametersOptionsInner",
    "CoreCourseGetContentsResponseInner",
    "CoreCourseGetContentsResponseInnerModulesInner",
    "CoreCourseGetContentsResponseInnerModulesInnerActivitybadge",
    "CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOf",
    "CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOfBadgeextraattributesInner",
    "CoreCourseGetContentsResponseInnerModulesInnerCompletiondata",
    "CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInner",
    "CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInnerRulevalue",
    "CoreCourseGetContentsResponseInnerModulesInnerContentsInner",
    "CoreCourseGetContentsResponseInnerModulesInnerContentsInnerTagsInner",
    "CoreCourseGetContentsResponseInnerModulesInnerContentsinfo",
    "CoreCourseGetContentsResponseInnerModulesInnerDatesInner",
    "CoreEnrolGetUsersCoursesResponseInner",
    "CoreEnrolGetUsersCoursesResponseInnerOverviewfilesInner",
    "CoreGroupGetCourseGroupsResponseInner",
    "CoreWebserviceGetSiteInfoResponse",
    "CoreWebserviceGetSiteInfoResponseAdvancedfeaturesInner",
    "CoreWebserviceGetSiteInfoResponseFunctionsInner",
    "GradereportUserGetGradeItemsResponse",
    "GradereportUserGetGradeItemsResponseUsergradesInner",
    "GradereportUserGetGradeItemsResponseUsergradesInnerGradeitemsInner",
    "GradereportUserGetGradeItemsResponseWarningsInner",
    "LoginToken200Response",
    "ModAssignGetAssignmentsResponse",
    "ModAssignGetAssignmentsResponseCoursesInner",
    "ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInner",
    "ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInnerConfigsInner",
    "ModAssignGetAssignmentsResponseWarningsInner",
    "ModAssignGetSubmissionsResponse",
    "ModAssignGetSubmissionsResponseAssignmentsInner",
    "ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInner",
    "ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInner",
    "ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInnerEditorfieldsInner",
    "ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInnerFileareasInner",
    "ModAssignListParticipantsResponseInner",
    "ModAssignListParticipantsResponseInnerCustomfieldsInner",
    "ModAssignListParticipantsResponseInnerEnrolledcoursesInner",
    "ModAssignListParticipantsResponseInnerGroupsInner",
    "ModAssignListParticipantsResponseInnerPreferencesInner",
    "ModAssignListParticipantsResponseInnerRolesInner",
    "ToolMobileGetPublicConfigResponse",
    "ToolMobileGetPublicConfigResponseIdentityprovidersInner",
]

if __import__("typing").TYPE_CHECKING:
    # import apis into sdk package
    from poodle_async_mini.api.default_api import DefaultApi as DefaultApi
    
    # import ApiClient
    from poodle_async_mini.api_response import ApiResponse as ApiResponse
    from poodle_async_mini.api_client import ApiClient as ApiClient
    from poodle_async_mini.configuration import Configuration as Configuration
    from poodle_async_mini.configuration import settings as settings
    from poodle_async_mini.exceptions import OpenApiException as OpenApiException
    from poodle_async_mini.exceptions import ApiTypeError as ApiTypeError
    from poodle_async_mini.exceptions import ApiValueError as ApiValueError
    from poodle_async_mini.exceptions import ApiKeyError as ApiKeyError
    from poodle_async_mini.exceptions import ApiAttributeError as ApiAttributeError
    from poodle_async_mini.exceptions import ApiException as ApiException
    
    # import models into sdk package
    from poodle_async_mini.models.core_course_get_contents_parameters_options_inner import CoreCourseGetContentsParametersOptionsInner as CoreCourseGetContentsParametersOptionsInner
    from poodle_async_mini.models.core_course_get_contents_response_inner import CoreCourseGetContentsResponseInner as CoreCourseGetContentsResponseInner
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner import CoreCourseGetContentsResponseInnerModulesInner as CoreCourseGetContentsResponseInnerModulesInner
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_activitybadge import CoreCourseGetContentsResponseInnerModulesInnerActivitybadge as CoreCourseGetContentsResponseInnerModulesInnerActivitybadge
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_activitybadge_one_of import CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOf as CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOf
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_activitybadge_one_of_badgeextraattributes_inner import CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOfBadgeextraattributesInner as CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOfBadgeextraattributesInner
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_completiondata import CoreCourseGetContentsResponseInnerModulesInnerCompletiondata as CoreCourseGetContentsResponseInnerModulesInnerCompletiondata
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_completiondata_details_inner import CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInner as CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInner
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_completiondata_details_inner_rulevalue import CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInnerRulevalue as CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInnerRulevalue
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_contents_inner import CoreCourseGetContentsResponseInnerModulesInnerContentsInner as CoreCourseGetContentsResponseInnerModulesInnerContentsInner
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_contents_inner_tags_inner import CoreCourseGetContentsResponseInnerModulesInnerContentsInnerTagsInner as CoreCourseGetContentsResponseInnerModulesInnerContentsInnerTagsInner
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_contentsinfo import CoreCourseGetContentsResponseInnerModulesInnerContentsinfo as CoreCourseGetContentsResponseInnerModulesInnerContentsinfo
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_dates_inner import CoreCourseGetContentsResponseInnerModulesInnerDatesInner as CoreCourseGetContentsResponseInnerModulesInnerDatesInner
    from poodle_async_mini.models.core_enrol_get_users_courses_response_inner import CoreEnrolGetUsersCoursesResponseInner as CoreEnrolGetUsersCoursesResponseInner
    from poodle_async_mini.models.core_enrol_get_users_courses_response_inner_overviewfiles_inner import CoreEnrolGetUsersCoursesResponseInnerOverviewfilesInner as CoreEnrolGetUsersCoursesResponseInnerOverviewfilesInner
    from poodle_async_mini.models.core_group_get_course_groups_response_inner import CoreGroupGetCourseGroupsResponseInner as CoreGroupGetCourseGroupsResponseInner
    from poodle_async_mini.models.core_webservice_get_site_info_response import CoreWebserviceGetSiteInfoResponse as CoreWebserviceGetSiteInfoResponse
    from poodle_async_mini.models.core_webservice_get_site_info_response_advancedfeatures_inner import CoreWebserviceGetSiteInfoResponseAdvancedfeaturesInner as CoreWebserviceGetSiteInfoResponseAdvancedfeaturesInner
    from poodle_async_mini.models.core_webservice_get_site_info_response_functions_inner import CoreWebserviceGetSiteInfoResponseFunctionsInner as CoreWebserviceGetSiteInfoResponseFunctionsInner
    from poodle_async_mini.models.gradereport_user_get_grade_items_response import GradereportUserGetGradeItemsResponse as GradereportUserGetGradeItemsResponse
    from poodle_async_mini.models.gradereport_user_get_grade_items_response_usergrades_inner import GradereportUserGetGradeItemsResponseUsergradesInner as GradereportUserGetGradeItemsResponseUsergradesInner
    from poodle_async_mini.models.gradereport_user_get_grade_items_response_usergrades_inner_gradeitems_inner import GradereportUserGetGradeItemsResponseUsergradesInnerGradeitemsInner as GradereportUserGetGradeItemsResponseUsergradesInnerGradeitemsInner
    from poodle_async_mini.models.gradereport_user_get_grade_items_response_warnings_inner import GradereportUserGetGradeItemsResponseWarningsInner as GradereportUserGetGradeItemsResponseWarningsInner
    from poodle_async_mini.models.login_token200_response import LoginToken200Response as LoginToken200Response
    from poodle_async_mini.models.mod_assign_get_assignments_response import ModAssignGetAssignmentsResponse as ModAssignGetAssignmentsResponse
    from poodle_async_mini.models.mod_assign_get_assignments_response_courses_inner import ModAssignGetAssignmentsResponseCoursesInner as ModAssignGetAssignmentsResponseCoursesInner
    from poodle_async_mini.models.mod_assign_get_assignments_response_courses_inner_assignments_inner import ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInner as ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInner
    from poodle_async_mini.models.mod_assign_get_assignments_response_courses_inner_assignments_inner_configs_inner import ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInnerConfigsInner as ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInnerConfigsInner
    from poodle_async_mini.models.mod_assign_get_assignments_response_warnings_inner import ModAssignGetAssignmentsResponseWarningsInner as ModAssignGetAssignmentsResponseWarningsInner
    from poodle_async_mini.models.mod_assign_get_submissions_response import ModAssignGetSubmissionsResponse as ModAssignGetSubmissionsResponse
    from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner import ModAssignGetSubmissionsResponseAssignmentsInner as ModAssignGetSubmissionsResponseAssignmentsInner
    from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner_submissions_inner import ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInner as ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInner
    from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner_submissions_inner_plugins_inner import ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInner as ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInner
    from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner_submissions_inner_plugins_inner_editorfields_inner import ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInnerEditorfieldsInner as ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInnerEditorfieldsInner
    from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner_submissions_inner_plugins_inner_fileareas_inner import ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInnerFileareasInner as ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInnerFileareasInner
    from poodle_async_mini.models.mod_assign_list_participants_response_inner import ModAssignListParticipantsResponseInner as ModAssignListParticipantsResponseInner
    from poodle_async_mini.models.mod_assign_list_participants_response_inner_customfields_inner import ModAssignListParticipantsResponseInnerCustomfieldsInner as ModAssignListParticipantsResponseInnerCustomfieldsInner
    from poodle_async_mini.models.mod_assign_list_participants_response_inner_enrolledcourses_inner import ModAssignListParticipantsResponseInnerEnrolledcoursesInner as ModAssignListParticipantsResponseInnerEnrolledcoursesInner
    from poodle_async_mini.models.mod_assign_list_participants_response_inner_groups_inner import ModAssignListParticipantsResponseInnerGroupsInner as ModAssignListParticipantsResponseInnerGroupsInner
    from poodle_async_mini.models.mod_assign_list_participants_response_inner_preferences_inner import ModAssignListParticipantsResponseInnerPreferencesInner as ModAssignListParticipantsResponseInnerPreferencesInner
    from poodle_async_mini.models.mod_assign_list_participants_response_inner_roles_inner import ModAssignListParticipantsResponseInnerRolesInner as ModAssignListParticipantsResponseInnerRolesInner
    from poodle_async_mini.models.tool_mobile_get_public_config_response import ToolMobileGetPublicConfigResponse as ToolMobileGetPublicConfigResponse
    from poodle_async_mini.models.tool_mobile_get_public_config_response_identityproviders_inner import ToolMobileGetPublicConfigResponseIdentityprovidersInner as ToolMobileGetPublicConfigResponseIdentityprovidersInner
    
else:
    from lazy_imports import LazyModule, as_package, load

    load(
        LazyModule(
            *as_package(__file__),
            ("__version__", __version__),
            ("__all__", __all__),
            """# import apis into sdk package
from poodle_async_mini.api.default_api import DefaultApi as DefaultApi

# import ApiClient
from poodle_async_mini.api_response import ApiResponse as ApiResponse
from poodle_async_mini.api_client import ApiClient as ApiClient
from poodle_async_mini.configuration import Configuration as Configuration
from poodle_async_mini.configuration import settings as settings
from poodle_async_mini.exceptions import OpenApiException as OpenApiException
from poodle_async_mini.exceptions import ApiTypeError as ApiTypeError
from poodle_async_mini.exceptions import ApiValueError as ApiValueError
from poodle_async_mini.exceptions import ApiKeyError as ApiKeyError
from poodle_async_mini.exceptions import ApiAttributeError as ApiAttributeError
from poodle_async_mini.exceptions import ApiException as ApiException

# import models into sdk package
from poodle_async_mini.models.core_course_get_contents_parameters_options_inner import CoreCourseGetContentsParametersOptionsInner as CoreCourseGetContentsParametersOptionsInner
from poodle_async_mini.models.core_course_get_contents_response_inner import CoreCourseGetContentsResponseInner as CoreCourseGetContentsResponseInner
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner import CoreCourseGetContentsResponseInnerModulesInner as CoreCourseGetContentsResponseInnerModulesInner
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_activitybadge import CoreCourseGetContentsResponseInnerModulesInnerActivitybadge as CoreCourseGetContentsResponseInnerModulesInnerActivitybadge
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_activitybadge_one_of import CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOf as CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOf
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_activitybadge_one_of_badgeextraattributes_inner import CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOfBadgeextraattributesInner as CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOfBadgeextraattributesInner
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_completiondata import CoreCourseGetContentsResponseInnerModulesInnerCompletiondata as CoreCourseGetContentsResponseInnerModulesInnerCompletiondata
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_completiondata_details_inner import CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInner as CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInner
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_completiondata_details_inner_rulevalue import CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInnerRulevalue as CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInnerRulevalue
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_contents_inner import CoreCourseGetContentsResponseInnerModulesInnerContentsInner as CoreCourseGetContentsResponseInnerModulesInnerContentsInner
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_contents_inner_tags_inner import CoreCourseGetContentsResponseInnerModulesInnerContentsInnerTagsInner as CoreCourseGetContentsResponseInnerModulesInnerContentsInnerTagsInner
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_contentsinfo import CoreCourseGetContentsResponseInnerModulesInnerContentsinfo as CoreCourseGetContentsResponseInnerModulesInnerContentsinfo
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_dates_inner import CoreCourseGetContentsResponseInnerModulesInnerDatesInner as CoreCourseGetContentsResponseInnerModulesInnerDatesInner
from poodle_async_mini.models.core_enrol_get_users_courses_response_inner import CoreEnrolGetUsersCoursesResponseInner as CoreEnrolGetUsersCoursesResponseInner
from poodle_async_mini.models.core_enrol_get_users_courses_response_inner_overviewfiles_inner import CoreEnrolGetUsersCoursesResponseInnerOverviewfilesInner as CoreEnrolGetUsersCoursesResponseInnerOverviewfilesInner
from poodle_async_mini.models.core_group_get_course_groups_response_inner import CoreGroupGetCourseGroupsResponseInner as CoreGroupGetCourseGroupsResponseInner
from poodle_async_mini.models.core_webservice_get_site_info_response import CoreWebserviceGetSiteInfoResponse as CoreWebserviceGetSiteInfoResponse
from poodle_async_mini.models.core_webservice_get_site_info_response_advancedfeatures_inner import CoreWebserviceGetSiteInfoResponseAdvancedfeaturesInner as CoreWebserviceGetSiteInfoResponseAdvancedfeaturesInner
from poodle_async_mini.models.core_webservice_get_site_info_response_functions_inner import CoreWebserviceGetSiteInfoResponseFunctionsInner as CoreWebserviceGetSiteInfoResponseFunctionsInner
from poodle_async_mini.models.gradereport_user_get_grade_items_response import GradereportUserGetGradeItemsResponse as GradereportUserGetGradeItemsResponse
from poodle_async_mini.models.gradereport_user_get_grade_items_response_usergrades_inner import GradereportUserGetGradeItemsResponseUsergradesInner as GradereportUserGetGradeItemsResponseUsergradesInner
from poodle_async_mini.models.gradereport_user_get_grade_items_response_usergrades_inner_gradeitems_inner import GradereportUserGetGradeItemsResponseUsergradesInnerGradeitemsInner as GradereportUserGetGradeItemsResponseUsergradesInnerGradeitemsInner
from poodle_async_mini.models.gradereport_user_get_grade_items_response_warnings_inner import GradereportUserGetGradeItemsResponseWarningsInner as GradereportUserGetGradeItemsResponseWarningsInner
from poodle_async_mini.models.login_token200_response import LoginToken200Response as LoginToken200Response
from poodle_async_mini.models.mod_assign_get_assignments_response import ModAssignGetAssignmentsResponse as ModAssignGetAssignmentsResponse
from poodle_async_mini.models.mod_assign_get_assignments_response_courses_inner import ModAssignGetAssignmentsResponseCoursesInner as ModAssignGetAssignmentsResponseCoursesInner
from poodle_async_mini.models.mod_assign_get_assignments_response_courses_inner_assignments_inner import ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInner as ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInner
from poodle_async_mini.models.mod_assign_get_assignments_response_courses_inner_assignments_inner_configs_inner import ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInnerConfigsInner as ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInnerConfigsInner
from poodle_async_mini.models.mod_assign_get_assignments_response_warnings_inner import ModAssignGetAssignmentsResponseWarningsInner as ModAssignGetAssignmentsResponseWarningsInner
from poodle_async_mini.models.mod_assign_get_submissions_response import ModAssignGetSubmissionsResponse as ModAssignGetSubmissionsResponse
from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner import ModAssignGetSubmissionsResponseAssignmentsInner as ModAssignGetSubmissionsResponseAssignmentsInner
from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner_submissions_inner import ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInner as ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInner
from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner_submissions_inner_plugins_inner import ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInner as ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInner
from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner_submissions_inner_plugins_inner_editorfields_inner import ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInnerEditorfieldsInner as ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInnerEditorfieldsInner
from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner_submissions_inner_plugins_inner_fileareas_inner import ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInnerFileareasInner as ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInnerFileareasInner
from poodle_async_mini.models.mod_assign_list_participants_response_inner import ModAssignListParticipantsResponseInner as ModAssignListParticipantsResponseInner
from poodle_async_mini.models.mod_assign_list_participants_response_inner_customfields_inner import ModAssignListParticipantsResponseInnerCustomfieldsInner as ModAssignListParticipantsResponseInnerCustomfieldsInner
from poodle_async_mini.models.mod_assign_list_participants_response_inner_enrolledcourses_inner import ModAssignListParticipantsResponseInnerEnrolledcoursesInner as ModAssignListParticipantsResponseInnerEnrolledcoursesInner
from poodle_async_mini.models.mod_assign_list_participants_response_inner_groups_inner import ModAssignListParticipantsResponseInnerGroupsInner as ModAssignListParticipantsResponseInnerGroupsInner
from poodle_async_mini.models.mod_assign_list_participants_response_inner_preferences_inner import ModAssignListParticipantsResponseInnerPreferencesInner as ModAssignListParticipantsResponseInnerPreferencesInner
from poodle_async_mini.models.mod_assign_list_participants_response_inner_roles_inner import ModAssignListParticipantsResponseInnerRolesInner as ModAssignListParticipantsResponseInnerRolesInner
from poodle_async_mini.models.tool_mobile_get_public_config_response import ToolMobileGetPublicConfigResponse as ToolMobileGetPublicConfigResponse
from poodle_async_mini.models.tool_mobile_get_public_config_response_identityproviders_inner import ToolMobileGetPublicConfigResponseIdentityprovidersInner as ToolMobileGetPublicConfigResponseIdentityprovidersInner

""",
            name=__name__,
            doc=__doc__,
        )
    )
